@@ -108,7 +108,7 @@ layout.format <- function(format, datetime.fmt="%Y-%m-%d %H:%M:%S")
     if (! is.null(substitute(...))) msg <- sprintf(msg, ...)
     the.level <- names(level)
     the.time <- format(Sys.time(), datetime.fmt)
-    the.namespace <- get_namespace()
+    the.namespace <- flog.namespace()
     #print(sys.calls())
     the.function <- tryCatch(sys.call(where)[[1]], error=function(e) "(shell)")
     #pattern <- c('~l','~t','~n','~f','~m')
